import { renderless, api } from '@opentinyvue/vue-renderless/action-sheet/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import { IconClose } from '@opentinyvue/vue-icon';
import Button from '@opentinyvue/vue-button';
import Drawer from '@opentinyvue/vue-drawer';
import BScroll from '@better-scroll/core';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  components: {
    TinyButton: Button,
    TinyDrawer: Drawer,
    IconClose: IconClose()
  },
  emits: ["update:modelValue", "update:visible", "hide", "close", "click"],
  props: [].concat(props, ["modelValue", "visible", "title", "showHeader", "showFooter", "showClose", "fullscreen", "customClass", "menus", "type", "mask", "maskClosable", "lockScroll", "flex", "beforeClose"]),
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api,
      extendOptions: {
        BScroll
      }
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "text-sm",
    attrs: {
      "data-tag": "tiny-action-sheet"
    }
  }, [_c("tiny-drawer", {
    ref: "drawer",
    attrs: {
      "title": _vm.title,
      "mask": _vm.mask,
      "flex": "",
      "before-close": _vm.beforeClose,
      "mask-closable": _vm.maskClosable,
      "lock-scroll": _vm.lockScroll,
      "show-header": false,
      "custom-class": _vm.m("rounded-t-lg", {
        "h-full": _vm.fullscreen
      }, {
        "max-h-[90%]": !_vm.fullscreen
      }, {
        "min-h-[theme(spacing.64)]": _vm.type !== "action"
      }, {
        "py-4": _vm.showHeader && _vm.type !== "action"
      }, _vm.customClass),
      "placement": "bottom",
      "visible": _vm.visible
    },
    on: {
      "update:visible": function updateVisible($event) {
        return _vm.$emit("update:visible", $event);
      }
    }
  }, [_vm.showHeader && _vm.type !== "action" ? _c("div", {
    ref: "header",
    staticClass: "flex flex-none leading-6 pb-4 px-4 text-base items-center",
    attrs: {
      "data-tag": "action-sheet-header"
    }
  }, [_c("div", {
    staticClass: "flex-1 flex items-center text-left"
  }, [_vm._t("header-left")], 2), _c("div", {
    staticClass: "min-w-[50%] max-w-[80%] px-4 text-center truncate font-bold"
  }, [_vm._v(_vm._s(_vm.title))]), _c("div", {
    staticClass: "flex-1 flex items-center justify-end"
  }, [_vm._t("header-right", function() {
    return [_vm.showClose ? _c("icon-close", {
      attrs: {
        "custom-class": "h-5 w-5 cursor-pointer"
      },
      on: {
        "click": _vm.close
      }
    }) : _vm._e()];
  })], 2)]) : _vm._e(), _vm._t("body-top"), _c("div", {
    ref: "body",
    class: ["flex-auto overflow-auto scrollbar-size-0", {
      "flex flex-col": _vm.flex
    }],
    attrs: {
      "data-tag": "action-sheet-body"
    }
  }, [_vm.type === "action" ? [_c("div", {
    staticClass: "flex flex-col h-full text-center",
    attrs: {
      "data-tag": "action-box"
    }
  }, [_vm.title ? _c("div", {
    staticClass: "flex-none flex items-center justify-center py-2.5 leading-5 text-sm text-color-none-hover border-b-0.5 border-color-bg-2",
    attrs: {
      "data-tag": "action-title"
    }
  }, [_c("span", {
    staticClass: "px-4"
  }, [_vm._v(_vm._s(_vm.title))])]) : _vm._e(), _c("div", {
    staticClass: "flex-auto min-h-[theme(spacing.12)]"
  }, _vm._l(_vm.menus, function(item, index) {
    return _c("div", {
      key: index,
      staticClass: "flex-none flex items-center justify-center h-12 text-base border-b-0.5 border-color-bg-2 cursor-pointer",
      on: {
        "click": function click($event) {
          $event.stopPropagation();
          return _vm.actionSelectOption(item, index);
        }
      }
    }, [_vm._t("default", function() {
      return [_c("span", {
        staticClass: "truncate px-4 text-color-text-primary font-medium"
      }, [_vm._v(_vm._s(item))])];
    }, {
      "data": item,
      "index": index
    })], 2);
  }), 0), _c("div", {
    staticClass: "flex-none flex items-center justify-center h-16 text-base border-t-8 border-color-bg-2 px-4 cursor-pointer",
    on: {
      "click": function click($event) {
        $event.stopPropagation();
        return _vm.close.apply(null, arguments);
      }
    }
  }, [_vm._v(" " + _vm._s(_vm.t("ui.base.cancel")) + " ")])])] : [_vm._t("default")]], 2), _vm._t("body-bottom"), _vm.showFooter ? _c("div", {
    ref: "footer",
    staticClass: "flex flex-none pt-2 justify-center",
    attrs: {
      "data-tag": "action-sheet-footer"
    }
  }, [_vm._t("footer", function() {
    return [_c("tiny-button", {
      staticClass: "flex-1 mx-4 sm:mx-0",
      attrs: {
        "tiny_mode": "mobile-first",
        "type": "primary"
      },
      on: {
        "click": _vm.confirm
      }
    }, [_vm._v(_vm._s(_vm.t("ui.button.confirm")))])];
  }, {
    "beforeClose": _vm.beforeClose
  })], 2) : _vm._e()], 2)], 1);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobileFirst as default };
